==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPFaultInjectionDelayExponentialDelayFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPFaultInjectionDelayExponentialDelayFluent<A extends HTTPFaultInjectionDelayExponentialDelayFluent<A>> extends BaseFluent<A>{
  public HTTPFaultInjectionDelayExponentialDelayFluent() {
  }
  public HTTPFaultInjectionDelayExponentialDelayFluent(HTTPFaultInjectionDelayExponentialDelay instance) {
    instance = (instance != null ? instance : new HTTPFaultInjectionDelayExponentialDelay());

    if (instance != null) {
      this.withExponentialDelay(instance.getExponentialDelay());
      this.withExponentialDelay(instance.getExponentialDelay());
    }
  }
  private String exponentialDelay;
  public String getExponentialDelay() {
    return this.exponentialDelay;
  }
  public A withExponentialDelay(String exponentialDelay) {
    this.exponentialDelay=exponentialDelay; return (A) this;
  }
  public boolean hasExponentialDelay() {
    return this.exponentialDelay != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPFaultInjectionDelayExponentialDelayFluent that = (HTTPFaultInjectionDelayExponentialDelayFluent) o;
    if (!java.util.Objects.equals(exponentialDelay, that.exponentialDelay)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(exponentialDelay,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (exponentialDelay != null) { sb.append("exponentialDelay:"); sb.append(exponentialDelay); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPFaultInjectionDelayExponentialDelayFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HTTPFaultInjectionDelayExponentialDelayFluent<A extends HTTPFaultInjectionDelayExponentialDelayFluent<A>> extends BaseFluent<A>{
  public HTTPFaultInjectionDelayExponentialDelayFluent() {
  }
  
  public HTTPFaultInjectionDelayExponentialDelayFluent(HTTPFaultInjectionDelayExponentialDelay instance) {
    this.copyInstance(instance);
  }
  private String exponentialDelay;
  
  protected void copyInstance(HTTPFaultInjectionDelayExponentialDelay instance) {
    instance = (instance != null ? instance : new HTTPFaultInjectionDelayExponentialDelay());
  
    if (instance != null) {
        this.withExponentialDelay(instance.getExponentialDelay());
        this.withExponentialDelay(instance.getExponentialDelay());
      }
  }
  
  public String getExponentialDelay() {
    return this.exponentialDelay;
  }
  
  public A withExponentialDelay(String exponentialDelay) {
    this.exponentialDelay=exponentialDelay; return (A) this;
  }
  
  public boolean hasExponentialDelay() {
    return this.exponentialDelay != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPFaultInjectionDelayExponentialDelayFluent that = (HTTPFaultInjectionDelayExponentialDelayFluent) o;
    if (!java.util.Objects.equals(exponentialDelay, that.exponentialDelay)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(exponentialDelay,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (exponentialDelay != null) { sb.append("exponentialDelay:"); sb.append(exponentialDelay); }
    sb.append("}");
    return sb.toString();
  }
  

}
